Structs
- V4LCapture
Device - The backend struct that interfaces with V4L2.
To see what this does, please see
CaptureBackendTrait.
Functions
- id_
to_ known_ camera_ control - Attempts to convert a
u32V4L2 Control ID into aKnownCameraControlIf the associated control is not found, this will returnNone(ColorEnable,Roll) - known_
camera_ control_ to_ id - Attempts to convert a
KnownCameraControlinto a V4L2 Control ID. If the associated control is not found, this will returnNone(ColorEnable,Roll) - query
- query v4l2 cameras